Quantiles for the exponential goodness-of-fit test. They are obtained
from the sample correlation from ANOVA test for exponential distribution.
The number of Monte Carlo iterations is 1.0E08.
Dataset representing the quantiles and the associated critical values for the Weibullness
test. They were obtained by conducting Monte Carlo simulations where the
sample correlation coefficients were calculated based on ANOVA test for exponential distribution.
We used 1.0E08 Monte Carlo iterations in the simulation.
Exponential.ANOVA.QuantilesThis data frame contains 998 rows and 1001 columns.