Learn R Programming

weibullness (version 2.26.9)

breakdown: Finite-sample breakdown point for the power-weighted repeated median (PWRM) estimators

Description

Calculates the lower and upper finite-sample breakdown points for the PWRM estimators of the regression coefficients.

Usage

breakdown.pwrm(x, power = 1)

Value

A numeric vector containing the lower and upper finite-sample breakdown points.

Arguments

x

a numeric vector of observations.

power

the power used in the weights of the PWRM method. The default value is 1.

Author

Chanseok Park

Details

For details on the lower and upper finite-sample breakdown points, see the Appendix of Park et al. (2024).

References

Park, C., X. Gao, and M. Wang (2024). Robust explicit estimators using the power-weighted repeated medians. Journal of Applied Statistics, 51(8), 1590--1608. tools:::Rd_expr_doi("10.1080/02664763.2023.2229969")

See Also

weibull.pwrm for parameter estimation using the PWRM method.

Examples

Run this code
attach(Wdata)

# See Section 5.1 of Park et al. (2024).
breakdown.pwrm(log(bearing), power=1)
breakdown.pwrm(log(bearing), power=2)
breakdown.pwrm(log(bearing), power=3)

Run the code above in your browser using DataLab