Learn R Programming

weibullness (version 2.26.9)

gumbel.mle: Maximum likelihood estimates of Gumbel distribution

Description

Calculates the maximum likelihood estimates of Gumbel distribution.

Usage

gumbel.mle(x, interval, tol = .Machine$double.eps^0.5, maxiter = 1000, trace = 0)

Value

An object of class "gumbel.estimate", a list with two parameter estimates.

Arguments

x

a numeric vector of observations.

interval

a vector containing the end-points of the interval to be estimated for the scale parameter.

tol

the desired accuracy (convergence tolerance).

maxiter

the maximum number of iterations.

trace

integer number; if positive, tracing information is produced. Higher values giving more details.

Author

Chanseok Park

Details

The Gumbel distribution has the cumulative distribution function $$F(x) = \exp\Big[-\exp\Big(-\frac{x-\mu}{\sigma}\Big)\Big],$$ where \(\sigma>0\). The location (\(\mu\)) and scale (\(\sigma\)) parameters are estimated using the maximum likelihood.

If the algorithm does not converge in maxiter steps, a warning is printed and the current approximation is returned (see also uniroot).

References

Gumbel, E. J. (1954). Statistical Theory of Extreme Values and Some Practical Applications (National Bureau of Standards Applied Mathematics Series 33) U.S. Government Printing Office, Washington, D.C.

Gentleman, J., Whitmore, G., Zwiers, F., and Ross, W. (1994). Extreme-value analysis of canadian wind speeds. In Gentleman, J. and Whitmore, G., editors, Case Studies in Data Analysis. Lecture Notes in Statistics, vol 94, Springer, New York, NY.

See Also

weibull.mle for the maximum likelihood parameter estimates of the Weibull distribution.

gumbel.gp for the parameter estimation using the Gumbel plot.

Examples

Run this code
data = c(79.5, 68.4, 74.0, 59.2, 74.0, 64.8, 64.8, 59.2, 79.5, 62.9,
59.2, 68.2, 64.8, 88.8, 88.8, 75.8, 68.4, 68.4, 61.0, 51.8,
62.9, 64.8, 61.0, 61.0, 70.3, 68.4, 55.5, 64.8, 77.7, 57.3,
48.1, 53.6, 55.5, 62.9, 61.0, 61.0, 51.8, 48.1)
gumbel.mle(data)

Run the code above in your browser using DataLab