Calculates the maximum likelihood estimates of the two-parameter Weibull distribution.
invweibull.mle(x, interval, tol = .Machine$double.eps^0.5, maxiter = 1000, trace = 0)An object of class "weibull.estimate", a list with
two parameter estimates.
a numeric vector of observations.
a vector containing the end-points of the interval to be estimated for the shape parameter.
the desired accuracy (convergence tolerance).
the maximum number of iterations.
integer number; if positive, tracing information is produced. Higher values giving more details.
Chanseok Park
The two-parameter inverse Weibull distribution has the cumulative distribution function $$F(X)=\exp(-(\theta/x)^\beta)$$ where \(x>0\), \(\beta>0\) and \(\theta>0\).
The shape (\(\beta\)) and scale (\(\theta\)) parameters are estimated
by calling weibull.mle on the reciprocally transformed data.
The maximum likelihood estimation on the the reciprocally transformed data is performed using the method by
Farnum and Booth (1997).
If interval is missing, the interval is given by the method in
Farnum and Booth (1997).
Convergence is declared either if f(x) == 0
or the change in x for one step of the algorithm is less than
tol (see also uniroot).
If the algorithm does not converge in maxiter steps,
a warning is printed and the current approximation is returned
(see also uniroot).
Farnum, N. R. and P. Booth (1997). Uniqueness of Maximum Likelihood Estimators of the 2-Parameter Weibull Distribution. IEEE Transactions on Reliability, 46, 523-525.
attach(Wdata)
invweibull.mle(1/bearing)
Run the code above in your browser using DataLab