iwp.test: Weibullness Test from a inverse Weibull Plot
Description
Performs the statistical test of inverse Weibullness
(Goodness-of-fit test for the inverse Weibull distribution)
using the sample correlation from the inverse Weibull plot.
Usage
iwp.test(x, a)
Value
A list with class "htest" containing the following components:
statistic
the value of the test statistic (sample correlation from the inverse Weibull plot)
p.value
the p-value for the test.
sample.size
sample size (missing observations are deleted).
method
a character string indicating the inverse Weibullness test.
data.name
a character string giving the name(s) of the data.
Arguments
x
a numeric vector of data values. Missing values are allowed,
but the number of non-missing values must be between 3 and 1000.
a
the offset fraction to be used; typically in (0,1). See ppoints().
Author
Chanseok Park
Details
The inverse Weibullness test is constructed using the sample correlation
which is calculated using the associated inverse Weibull plot.
The critical value is then looked up in IW.Plot.Quantiles.
There is print method for class "htest".
References
Vogel, R. M. and C. N. Kroll (1989).
Low-Flow Frequency Analysis Using Probability-Plot Correlation Coefficients.
Journal of Water Resources Planning and Management,
115, 338-357.
See Also
wp.test for performing the Weibullness test.
ks.test for performing the Kolmogorov-Smirnov test for the goodness of fit test of two samples.
shapiro.test for performing the Shapiro-Wilk test for normality.