Learn R Programming

weibullness (version 2.26.9)

regr.rm: Estimates of the intercept and slope parameters of a simple linear regression using the repeated median (RM).

Description

Calculates robust estimates of the intercept and slope parameters of a simple linear regression using the RM method.

Usage

regr.rm(x, y)

Value

An object of class weibull.estimate, which is a list containing the estimates of the intercept and slope parameters.

Arguments

x

a numeric vector of covariate observations.

y

a numeric vector of response observations.

Author

Chanseok Park

Details

regr.rm obtains robust estimates of the intercept and slope parameters using the RM method. These estimates can be used to estimate the shape and scale parameters of the Weibull distribution from a Weibull plot.

The regr.rm function can also be used to estimate the Weibull parameters, as shown in the examples below.

References

Boudt, K. and D. Caliskan and C. Croux (2011). obust explicit estimators of Weibull parameters. Metrika, 73, 187-209.

See Also

regr.pwrm for parameter estimation using the power-weighted repeated median (PWRM) method.

weibull.rm for parameter estimation using the PWRM method.

Examples

Run this code
data <- rweibull(10, shape = 2)

x <- sort(log(data))
y <- log(-log(1 - ppoints(x)))
para <- as.numeric(regr.rm(x, y))
c(para[2], exp(-para[1] / para[2]))

weibull.rm(data)

Run the code above in your browser using DataLab