weibull.mle for the parameter estimation using the maximum likelihood method.
weibull.wp for the parameter estimation using the Weibull plot.
weibull.pwrm for the parameter estimation using the power-weighted repeated median (PWRM) method.
fitdistr for maximum-likelihood fitting of univariate distributions in package MASS.