Learn R Programming

weibullness (version 2.26.9)

weibull.seki: Maximum likelihood estimates of two-parameter Weibull distribution

Description

Calculates the maximum likelihood estimates of two-parameter Weibull distribution.

Usage

weibull.seki(x)

Value

An object of class "weibull.estimate", a list with two parameter estimates.

Arguments

x

a numeric vector of observations.

Author

Chanseok Park

Details

The two-parameter Weibull distribution has the cumulative distribution function $$F(x) = 1 - \exp\Big[ - \Big( \frac{x}{\beta} \Big)^{\alpha} \Big]$$. The shape (\(\alpha\)) and scale (\(\beta\)) parameters are estimated the Seki method.

References

Seki, T. and S. Yokoyama (1993). Simple and robust estimation of the Weibull parameters. Microelectronics Reliability, 33, 45-52.

See Also

weibull.mle for the parameter estimation using the maximum likelihood method.

weibull.wp for the parameter estimation using the Weibull plot.

weibull.rm for robust parameter estimation using the repeated median (RM) method.

weibull.pwrm for robust parameter estimation using the power-weighted repeated median (PWRM) method.

fitdistr for maximum-likelihood fitting of univariate distributions in package MASS.

Examples

Run this code
attach(Wdata)
weibull.seki(bearing)

Run the code above in your browser using DataLab