Calculates the estimate of the threshold parameter.
weibull.threshold(x, a, interval.threshold, extendInt="downX")weibull.threshold returns a numeric value.
a numeric vector of observations.
the offset fraction to be used; typically in (0,1).
a vector containing the end-points of the interval to be estimated for the threshold parameter.
character string specifying if the interval c(left,right) should be extended or directly produce an error when f() has no differing signs at the endpoints. The default, "downX", keep lowering the the left end of the interval so that f() has different signs. See uniroot.
Chanseok Park
The three-parameter Weibull distribution has the cumulative distribution function $$F(x) = 1 -\exp\Big[-\Big( \frac{x-\theta}{\beta}\Big)^{\alpha}\Big],$$ where \(x>\theta\). The threshold parameter (\(\theta\)) is estimated by maximizing the correlation function from the Weibull plot.
The choice of a follows ppoints function.
If interval.threshold is missing, the interval is initially given
by (min(x)-sd(x), min(x)). If this interval does not include
the estimate, its lower bound is extended (see also uniroot).
Park, C. (2018). A Note on the Existence of the Location Parameter Estimate of the Three-Parameter Weibull Model Using the Weibull Plot. Mathematical Problems in Engineering, 2018, 6056975. tools:::Rd_expr_doi("10.1155/2018/6056975")
Park, C. (2017). Weibullness test and parameter estimation of the three-parameter Weibull model using the sample correlation coefficient. International Journal of Industrial Engineering - Theory, Applications and Practice, 24(4), 376-391. tools:::Rd_expr_doi("10.23055/ijietap.2017.24.4.2848")
weibull.mle for the maximum likelihood estimate.
weibull.wp for the parameter estimation using the Weibull plot.
attach(Wdata)
weibull.threshold(bearing)
Run the code above in your browser using DataLab