gumbel.gp: Estimate of location and scale parameters of the Gumbel distribution
Description
Calculates the estimates of the location and scale
parameters from the Gumbel probability plot.
Usage
gumbel.gp(x, n, a)
Value
An object of class "gumbel.estimate", a list with
two parameter estimates
Arguments
x
a numeric vector of observations.
n
The number of observations is needed if there is right-censoring.
a
the offset fraction to be used; typically in (0,1). See ppoints.
Author
Chanseok Park
Details
The Gumbel distribution has the cumulative distribution function
$$F(x) = \exp\Big[-\exp\Big(-\frac{x-\mu}{\sigma}\Big)\Big],$$
where \(\sigma>0\).
The location (\(\mu\)) and scale (\(\sigma\)) parameters are estimated
using the intercept and slope estimates from the
Gumbel probability plot.
gumbel.gp obtains the estimates of the location and scale.
See Also
gumbel.mle for the maximum likelihood parameter estimates.
weibull.wp for the parameter estimation using the Weibull plot.