regr.pwrm: Estimates of the intercept and slope parameters of a simple linear regression using the power-weighted repeated median (PWRM).
Description
Calculates robust estimates of the intercept and slope parameters of a simple linear regression using the PWRM method.
Usage
regr.pwrm(x, y, weight = FALSE, power = 1)
Value
An object of class weibull.estimate, which is a list containing the estimates of the intercept and slope parameters.
Arguments
x
a numeric vector of covariate observations.
y
a numeric vector of response observations.
weight
logical. If FALSE (default), the ordinary median is used; if TRUE, the weighted median is used.
power
the power used in the weights of the PWRM method. The default value is 1.
Author
Chanseok Park
Details
regr.pwrm obtains robust estimates of the intercept and slope parameters using the PWRM method. These estimates can be used to estimate the shape and scale parameters of the Weibull distribution from a Weibull plot.
The regr.pwrm function can also be used to estimate the Weibull parameters, as shown in the examples below.
References
Park, C., X. Gao, and M. Wang (2024).
Robust explicit estimators using the power-weighted repeated medians.
Journal of Applied Statistics, 51(8), 1590--1608.
tools:::Rd_expr_doi("10.1080/02664763.2023.2229969")
See Also
regr.rm for parameter estimation using the repeated median (RM) method.
weibull.pwrm for parameter estimation using the PWRM method.