Calculates the estimates of the shape and scale parameters.
weibull.pwrm(x, a, weight=FALSE, power=1)An object of class weibull.estimate, a list with two parameter estimates
a numeric vector of observations.
the offset fraction to be used; typically in (0,1). See ppoints.
FALSE (default) uses the ordinary median, while TRUE uses the weighted median.
power is the power in the weight of the PWRM method.
The default value is 1.
The weibull.pwrm function with weight=FALSE and power=1
is essentially the same as weibull.rm function.
Chanseok Park
weibull.pwrm obtains the robust estimates of the shape and scale parameters
using the intercept and slope estimates using the PWRM method from the Weibull plot.
Park, C., X. Gao, and M. Wang (2024). Robust explicit estimators using the power-weighted repeated medians. Journal of Applied Statistics, 51(8), 1590-1608. tools:::Rd_expr_doi("10.1080/02664763.2023.2229969")
weibull.mle for the parameter estimation using the maximum likelihood method.
weibull.wp for the parameter estimation using the Weibull plot.
weibull.rm for the parameter estimation using the repeated median (RM) method.
fitdistr for maximum-likelihood fitting of univariate distributions in package MASS.
attach(Wdata)
weibull.pwrm(bearing)
Run the code above in your browser using DataLab